'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.setFieldValue = exports.moveFieldValue = exports.deleteFieldValue = exports.addFieldInstance = exports.saveRecord = exports.readRecord = exports.createNewRecord = exports.SET_FIELD_VALUE = exports.MOVE_FIELD_VALUE = exports.DELETE_FIELD_VALUE = exports.ADD_FIELD_INSTANCE = exports.RECORD_SAVE_REJECTED = exports.RECORD_SAVE_FULFILLED = exports.RECORD_SAVE_STARTED = exports.RECORD_READ_REJECTED = exports.RECORD_READ_FULFILLED = exports.RECORD_READ_STARTED = exports.CREATE_NEW_RECORD = undefined;

var _cspace = require('./cspace');

var _cspace2 = _interopRequireDefault(_cspace);

var _reducers = require('../reducers');

var _recordDataHelpers = require('../helpers/recordDataHelpers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var CREATE_NEW_RECORD = exports.CREATE_NEW_RECORD = 'CREATE_NEW_RECORD'; /* global window */

var RECORD_READ_STARTED = exports.RECORD_READ_STARTED = 'RECORD_READ_STARTED';
var RECORD_READ_FULFILLED = exports.RECORD_READ_FULFILLED = 'RECORD_READ_FULFILLED';
var RECORD_READ_REJECTED = exports.RECORD_READ_REJECTED = 'RECORD_READ_REJECTED';
var RECORD_SAVE_STARTED = exports.RECORD_SAVE_STARTED = 'RECORD_SAVE_STARTED';
var RECORD_SAVE_FULFILLED = exports.RECORD_SAVE_FULFILLED = 'RECORD_SAVE_FULFILLED';
var RECORD_SAVE_REJECTED = exports.RECORD_SAVE_REJECTED = 'RECORD_SAVE_REJECTED';
var ADD_FIELD_INSTANCE = exports.ADD_FIELD_INSTANCE = 'ADD_FIELD_INSTANCE';
var DELETE_FIELD_VALUE = exports.DELETE_FIELD_VALUE = 'DELETE_FIELD_VALUE';
var MOVE_FIELD_VALUE = exports.MOVE_FIELD_VALUE = 'MOVE_FIELD_VALUE';
var SET_FIELD_VALUE = exports.SET_FIELD_VALUE = 'SET_FIELD_VALUE';

// TODO: Accept csid to clone.

// Force this to be async, to be consistent with reading an existing record.
var createNewRecord = exports.createNewRecord = function createNewRecord(serviceConfig) {
  return function (dispatch) {
    return new Promise(function (resolve) {
      window.setTimeout(function () {
        resolve();
      }, 0);
    }).then(function () {
      return dispatch({
        type: CREATE_NEW_RECORD,
        meta: {
          serviceConfig: serviceConfig
        }
      });
    });
  };
};

var readRecord = exports.readRecord = function readRecord(serviceConfig, csid) {
  return function (dispatch) {
    dispatch({
      type: RECORD_READ_STARTED,
      meta: {
        serviceConfig: serviceConfig,
        csid: csid
      }
    });

    var serviceName = serviceConfig.name;

    return (0, _cspace2.default)().read(serviceName + '/' + csid).then(function (response) {
      return dispatch({
        type: RECORD_READ_FULFILLED,
        payload: response,
        meta: {
          serviceConfig: serviceConfig,
          csid: csid
        }
      });
    }).catch(function (error) {
      return dispatch({
        type: RECORD_READ_REJECTED,
        payload: error,
        meta: {
          serviceConfig: serviceConfig,
          csid: csid
        }
      });
    });
  };
};

var saveRecord = exports.saveRecord = function saveRecord(recordType, serviceConfig, csid, replace) {
  return function (dispatch, getState) {
    dispatch({
      type: RECORD_SAVE_STARTED,
      meta: {
        serviceConfig: serviceConfig,
        csid: csid
      }
    });

    var serviceName = serviceConfig.name;
    var data = (0, _reducers.getRecordData)(getState(), csid);

    var config = {
      data: (0, _recordDataHelpers.prepareForSending)(data).toJS()
    };

    var save = csid ? (0, _cspace2.default)().update(serviceName + '/' + csid, config) : (0, _cspace2.default)().create(serviceName, config);

    return save.then(function (response) {
      var action = dispatch({
        type: RECORD_SAVE_FULFILLED,
        payload: response,
        meta: {
          serviceConfig: serviceConfig,
          csid: csid
        }
      });

      if (response.status === 201 && response.headers.location) {
        // Redirect to the new record.

        var location = response.headers.location;
        var newRecordCsid = location.substring(location.lastIndexOf('/') + 1);

        replace('/record/' + recordType + '/' + newRecordCsid);
      }

      return action;
    }).catch(function (error) {
      return dispatch({
        type: RECORD_SAVE_REJECTED,
        payload: error,
        meta: {
          serviceConfig: serviceConfig,
          csid: csid
        }
      });
    });
  };
};

var addFieldInstance = exports.addFieldInstance = function addFieldInstance(csid, path) {
  return {
    type: ADD_FIELD_INSTANCE,
    meta: {
      csid: csid,
      path: path
    }
  };
};

var deleteFieldValue = exports.deleteFieldValue = function deleteFieldValue(csid, path) {
  return {
    type: DELETE_FIELD_VALUE,
    meta: {
      csid: csid,
      path: path
    }
  };
};

var moveFieldValue = exports.moveFieldValue = function moveFieldValue(csid, path, newPosition) {
  return {
    type: MOVE_FIELD_VALUE,
    meta: {
      csid: csid,
      path: path,
      newPosition: newPosition
    }
  };
};

var setFieldValue = exports.setFieldValue = function setFieldValue(csid, path, value) {
  return {
    type: SET_FIELD_VALUE,
    payload: value,
    meta: {
      csid: csid,
      path: path
    }
  };
};