'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactIntl = require('react-intl');

var _cspaceInput = require('cspace-input');

var _QuickAdd = require('./QuickAdd');

var _QuickAdd2 = _interopRequireDefault(_QuickAdd);

var _parseAuthoritySpec = require('../../helpers/parseAuthoritySpec');

var _parseAuthoritySpec2 = _interopRequireDefault(_parseAuthoritySpec);

var _refNameHelpers = require('../../helpers/refNameHelpers');

var _AuthorityControlledInput = require('../../../styles/cspace-ui/AuthorityControlledInput.css');

var _AuthorityControlledInput2 = _interopRequireDefault(_AuthorityControlledInput);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var pathHelpers = _cspaceInput.helpers.pathHelpers;
var FilteringDropdownMenuInput = _cspaceInput.baseComponents.FilteringDropdownMenuInput;

var propTypes = _extends({}, FilteringDropdownMenuInput.propTypes, {
  addTerm: _react.PropTypes.func,
  intl: _reactIntl.intlShape,
  findMatchingTerms: _react.PropTypes.func,
  matches: _react.PropTypes.object,
  minLength: _react.PropTypes.number,
  recordPlugins: _react.PropTypes.object
});

var defaultProps = {
  // TODO: Make configurable
  minLength: 3
};

var messages = (0, _reactIntl.defineMessages)({
  moreCharsRequired: {
    'id': 'authorityControlledInput.moreCharsRequired',
    'defaultMessage': 'Continue typing to find matching terms'
  },
  count: {
    'id': 'authorityControlledInput.count',
    'defaultMessage': '{count, plural, =0 {No matches} one {# match} other {# matches}} found'
  }
});

var getOptions = function getOptions(authority, matches, partialTerm, recordPlugins) {
  var authorities = (0, _parseAuthoritySpec2.default)(authority);
  var options = [];

  if (matches) {
    (function () {
      var partialTermMatch = matches.get(partialTerm);

      if (partialTermMatch) {
        authorities.forEach(function (authoritySpec) {
          var authorityName = authoritySpec.authorityName,
              vocabularyName = authoritySpec.vocabularyName;


          var authorityServiceName = recordPlugins[authorityName].serviceConfig.name;
          var authorityMatch = partialTermMatch.getIn([authorityServiceName, vocabularyName]);

          if (authorityMatch) {
            var items = authorityMatch.get('items');

            if (items) {
              var authorityOptions = items.map(function (item) {
                return {
                  value: item.refName,
                  label: item.termDisplayName
                };
              });

              options.push.apply(options, _toConsumableArray(authorityOptions));
            }
          }
        });
      }
    })();
  }

  return options;
};

var isPending = function isPending(authority, matches, partialTerm, recordPlugins) {
  var authorities = (0, _parseAuthoritySpec2.default)(authority);
  var foundPending = false;

  if (matches) {
    (function () {
      var partialTermMatch = matches.get(partialTerm);

      if (partialTermMatch) {
        authorities.forEach(function (authoritySpec) {
          var authorityName = authoritySpec.authorityName,
              vocabularyName = authoritySpec.vocabularyName;


          var authorityServiceName = recordPlugins[authorityName].serviceConfig.name;
          var authorityMatch = partialTermMatch.getIn([authorityServiceName, vocabularyName]);

          if (authorityMatch) {
            foundPending = foundPending || authorityMatch.get('isSearchPending') || authorityMatch.get('isAddPending');
          }
        });
      }
    })();
  }

  return foundPending;
};

var getNewTerm = function getNewTerm(authority, matches, partialTerm, recordPlugins) {
  var authorities = (0, _parseAuthoritySpec2.default)(authority);
  var newTerm = null;

  if (matches) {
    (function () {
      var partialTermMatch = matches.get(partialTerm);

      if (partialTermMatch) {
        authorities.forEach(function (authoritySpec) {
          var authorityName = authoritySpec.authorityName,
              vocabularyName = authoritySpec.vocabularyName;


          var authorityServiceName = recordPlugins[authorityName].serviceConfig.name;
          var authorityMatch = partialTermMatch.getIn([authorityServiceName, vocabularyName]);

          if (authorityMatch) {
            newTerm = newTerm || authorityMatch.get('newTerm');
          }
        });
      }
    })();
  }

  return newTerm;
};

var AuthorityControlledInput = function (_Component) {
  _inherits(AuthorityControlledInput, _Component);

  function AuthorityControlledInput(props) {
    _classCallCheck(this, AuthorityControlledInput);

    var _this = _possibleConstructorReturn(this, (AuthorityControlledInput.__proto__ || Object.getPrototypeOf(AuthorityControlledInput)).call(this, props));

    _this.findMatchingTerms = _this.findMatchingTerms.bind(_this);
    _this.handleDropdownInputCommit = _this.handleDropdownInputCommit.bind(_this);
    _this.handleDropdownInputRef = _this.handleDropdownInputRef.bind(_this);

    _this.state = {
      partialTerm: null,
      value: props.value
    };
    return _this;
  }

  _createClass(AuthorityControlledInput, [{
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps(nextProps) {
      var newTerm = getNewTerm(nextProps.authority, nextProps.matches, this.state.partialTerm, nextProps.recordPlugins);

      var hadNewTerm = getNewTerm(this.props.authority, this.props.matches, this.state.partialTerm, this.props.recordPlugins);

      if (newTerm && !hadNewTerm) {
        this.commit(newTerm.getIn(['document', 'ns2:collectionspace_core', 'refName']));
        this.dropdownInput.close();
      } else {
        var newState = {
          value: nextProps.value
        };

        if (!isPending(nextProps.authority, nextProps.matches, this.state.partialTerm, nextProps.recordPlugins)) {
          newState.options = getOptions(nextProps.authority, nextProps.matches, this.state.partialTerm, nextProps.recordPlugins);
        }

        this.setState(newState);
      }
    }
  }, {
    key: 'commit',
    value: function commit(value) {
      this.setState({
        options: [],
        partialTerm: null,
        value: value
      });

      var onCommit = this.props.onCommit;


      if (onCommit) {
        onCommit(pathHelpers.getPath(this.props), value);
      }
    }
  }, {
    key: 'findMatchingTerms',
    value: function findMatchingTerms(partialTerm) {
      var _props = this.props,
          authority = _props.authority,
          findMatchingTerms = _props.findMatchingTerms,
          matches = _props.matches,
          minLength = _props.minLength,
          recordPlugins = _props.recordPlugins;


      var newState = {
        partialTerm: partialTerm
      };

      var searchNeeded = findMatchingTerms && partialTerm && partialTerm.length >= minLength && (!matches || !matches.has(partialTerm));

      if (searchNeeded) {
        // TODO: Pause to debounce
        findMatchingTerms(partialTerm);
      } else {
        newState.options = getOptions(authority, matches, partialTerm, recordPlugins);
      }

      this.setState(newState);
    }
  }, {
    key: 'handleDropdownInputCommit',
    value: function handleDropdownInputCommit(path, value) {
      this.commit(value);
    }
  }, {
    key: 'handleDropdownInputRef',
    value: function handleDropdownInputRef(ref) {
      this.dropdownInput = ref;
    }
  }, {
    key: 'renderQuickAdd',
    value: function renderQuickAdd() {
      var _props2 = this.props,
          addTerm = _props2.addTerm,
          authority = _props2.authority,
          minLength = _props2.minLength,
          recordPlugins = _props2.recordPlugins;
      var partialTerm = this.state.partialTerm;


      if (partialTerm && partialTerm.length >= minLength) {
        return _react2.default.createElement(_QuickAdd2.default, {
          add: addTerm,
          authority: authority,
          displayName: partialTerm,
          recordPlugins: recordPlugins
        });
      }

      return null;
    }
  }, {
    key: 'render',
    value: function render() {
      var _props3 = this.props,
          intl = _props3.intl,
          authority = _props3.authority,
          matches = _props3.matches,
          minLength = _props3.minLength,
          recordPlugins = _props3.recordPlugins,
          addTerm = _props3.addTerm,
          findMatchingTerms = _props3.findMatchingTerms,
          remainingProps = _objectWithoutProperties(_props3, ['intl', 'authority', 'matches', 'minLength', 'recordPlugins', 'addTerm', 'findMatchingTerms']);

      var _state = this.state,
          options = _state.options,
          partialTerm = _state.partialTerm,
          value = _state.value;


      var moreCharsRequired = typeof partialTerm !== 'undefined' && partialTerm !== null && partialTerm.length < minLength;

      var formatStatusMessage = moreCharsRequired ? function () {
        return intl.formatMessage(messages.moreCharsRequired);
      } : function (count) {
        return intl.formatMessage(messages.count, { count: count });
      };

      var className = isPending(authority, matches, partialTerm, recordPlugins) ? _AuthorityControlledInput2.default.searching : _AuthorityControlledInput2.default.normal;

      return _react2.default.createElement(FilteringDropdownMenuInput, _extends({}, remainingProps, {
        className: className,
        filter: this.findMatchingTerms,
        formatStatusMessage: formatStatusMessage,
        menuFooter: this.renderQuickAdd(),
        options: options,
        ref: this.handleDropdownInputRef,
        value: value,
        valueLabel: (0, _refNameHelpers.getDisplayName)(value),
        onCommit: this.handleDropdownInputCommit
      }));
    }
  }]);

  return AuthorityControlledInput;
}(_react.Component);

exports.default = AuthorityControlledInput;


AuthorityControlledInput.propTypes = propTypes;
AuthorityControlledInput.defaultProps = defaultProps;