'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ConnectedAuthorityControlledInput = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _reactRedux = require('react-redux');

var _reactIntl = require('react-intl');

var _warning = require('warning');

var _warning2 = _interopRequireDefault(_warning);

var _parseAuthoritySpec = require('../../helpers/parseAuthoritySpec');

var _parseAuthoritySpec2 = _interopRequireDefault(_parseAuthoritySpec);

var _AuthorityControlledInput = require('../../components/input/AuthorityControlledInput');

var _AuthorityControlledInput2 = _interopRequireDefault(_AuthorityControlledInput);

var _partialTermSearch = require('../../actions/partialTermSearch');

var _withRecordPlugins = require('../../enhancers/withRecordPlugins');

var _withRecordPlugins2 = _interopRequireDefault(_withRecordPlugins);

var _reducers = require('../../reducers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var mapStateToProps = function mapStateToProps(state) {
  return {
    matches: (0, _reducers.getPartialTermSearchMatches)(state)
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch, ownProps) {
  var authority = ownProps.authority,
      recordPlugins = ownProps.recordPlugins;


  var authorities = (0, _parseAuthoritySpec2.default)(authority);

  return {
    addTerm: function addTerm(authorityName, vocabularyName, displayName) {
      var recordType = recordPlugins[authorityName];

      process.env.NODE_ENV !== 'production' ? (0, _warning2.default)(recordType, 'The authority record type \'' + authorityName + '\' is not configured. Check the authority prop of the input with name \'' + ownProps.name + '\'.') : void 0;

      if (recordType) {
        var serviceConfig = recordType.serviceConfig;

        if (serviceConfig && serviceConfig.vocabularies && serviceConfig.vocabularies[vocabularyName]) {
          dispatch((0, _partialTermSearch.addTerm)(serviceConfig, vocabularyName, displayName));
        }
      }
    },
    findMatchingTerms: function findMatchingTerms(partialTerm) {
      authorities.forEach(function (authoritySpec) {
        var authorityName = authoritySpec.authorityName,
            vocabularyName = authoritySpec.vocabularyName;


        var recordType = recordPlugins[authorityName];

        process.env.NODE_ENV !== 'production' ? (0, _warning2.default)(recordType, 'The authority record type \'' + authorityName + '\' is not configured. Check the authority prop of the input with name \'' + ownProps.name + '\'.') : void 0;

        if (recordType) {
          var serviceConfig = recordType.serviceConfig;

          if (serviceConfig && serviceConfig.vocabularies && serviceConfig.vocabularies[vocabularyName]) {
            dispatch((0, _partialTermSearch.findMatchingTerms)(serviceConfig, vocabularyName, partialTerm));
          }
        }
      });
    },
    onClose: function onClose() {
      dispatch((0, _partialTermSearch.clearMatchedTerms)());
    }
  };
};

var ConnectedAuthorityControlledInput = exports.ConnectedAuthorityControlledInput = (0, _reactRedux.connect)(mapStateToProps, mapDispatchToProps)(_AuthorityControlledInput2.default);

var IntlAwareConnectedAuthorityControlledInput = (0, _reactIntl.injectIntl)((0, _withRecordPlugins2.default)(ConnectedAuthorityControlledInput));

IntlAwareConnectedAuthorityControlledInput.propTypes = _extends({}, _AuthorityControlledInput2.default.propTypes, {
  authority: _react.PropTypes.string.isRequired,
  recordPlugins: _react.PropTypes.object
});

exports.default = IntlAwareConnectedAuthorityControlledInput;