'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.initConfig = exports.mergeConfig = exports.applyPlugins = exports.applyPlugin = exports.evaluatePlugin = undefined;

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _merge = require('lodash/merge');

var _merge2 = _interopRequireDefault(_merge);

var _warning = require('warning');

var _warning2 = _interopRequireDefault(_warning);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var evaluatePlugin = exports.evaluatePlugin = function evaluatePlugin(plugin, pluginContext) {
  var pluginType = typeof plugin === 'undefined' ? 'undefined' : _typeof(plugin);

  var isValidType = plugin && (pluginType === 'function' || pluginType === 'object' && !Array.isArray(plugin));

  process.env.NODE_ENV !== 'production' ? (0, _warning2.default)(isValidType, 'A plugin must be an object or a function.') : void 0;

  if (!isValidType) {
    return {};
  }

  return pluginType === 'object' ? plugin : plugin(pluginContext);
};

var applyPlugin = exports.applyPlugin = function applyPlugin(targetConfig, plugin, pluginContext) {
  var pluginConfigContribution = evaluatePlugin(plugin, pluginContext);

  /* eslint-disable no-use-before-define */
  return mergeConfig(targetConfig, pluginConfigContribution, pluginContext);
  /* eslint-enable no-use-before-define */
};

var applyPlugins = exports.applyPlugins = function applyPlugins(targetConfig, plugins, pluginContext) {
  var isArray = Array.isArray(plugins);

  process.env.NODE_ENV !== 'production' ? (0, _warning2.default)(isArray, 'Plugins must be an array.') : void 0;

  if (!isArray) {
    return targetConfig;
  }

  return plugins.reduce(function (updatedConfig, plugin) {
    return applyPlugin(updatedConfig, plugin, pluginContext);
  }, targetConfig);
};

var mergeConfig = exports.mergeConfig = function mergeConfig(targetConfig, sourceConfig, pluginContext) {
  var pluginsAppliedConfig = 'plugins' in sourceConfig ? applyPlugins(targetConfig, sourceConfig.plugins, pluginContext) : targetConfig;

  var mergedConfig = (0, _merge2.default)({}, pluginsAppliedConfig, sourceConfig);

  delete mergedConfig.plugins;

  return mergedConfig;
};

var initConfig = exports.initConfig = function initConfig(config, pluginContext) {
  return mergeConfig({}, config, pluginContext);
};