'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _cspaceInput = require('cspace-input');

var _AuthorityControlledInputContainer = require('../../../containers/input/AuthorityControlledInputContainer');

var _AuthorityControlledInputContainer2 = _interopRequireDefault(_AuthorityControlledInputContainer);

var _OptionControlledInputContainer = require('../../../containers/input/OptionControlledInputContainer');

var _OptionControlledInputContainer2 = _interopRequireDefault(_OptionControlledInputContainer);

var _VocabularyControlledInputContainer = require('../../../containers/input/VocabularyControlledInputContainer');

var _VocabularyControlledInputContainer2 = _interopRequireDefault(_VocabularyControlledInputContainer);

var _PanelContainer = require('../../../containers/layout/PanelContainer');

var _PanelContainer2 = _interopRequireDefault(_PanelContainer);

var _Row = require('../../../components/layout/Row');

var _Row2 = _interopRequireDefault(_Row);

var _recordDataHelpers = require('../../../helpers/recordDataHelpers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var labelable = _cspaceInput.enhancers.labelable,
    repeatable = _cspaceInput.enhancers.repeatable;


var AuthorityControlledInput = repeatable(labelable(_AuthorityControlledInputContainer2.default));
var OptionControlledInput = repeatable(labelable(_OptionControlledInputContainer2.default));
var VocabularyControlledInput = repeatable(labelable(_VocabularyControlledInputContainer2.default));

var CompoundInput = _cspaceInput.components.CompoundInput,
    DateInput = _cspaceInput.components.DateInput,
    IDGeneratorInput = _cspaceInput.components.IDGeneratorInput,
    StructuredDateInput = _cspaceInput.components.StructuredDateInput,
    TextInput = _cspaceInput.components.TextInput;

exports.default = function (pluginContext) {
  var React = pluginContext.React;


  return React.createElement(
    CompoundInput,
    { defaultChildSubpath: (0, _recordDataHelpers.getPartPropertyName)('collectionobjects_common') },
    React.createElement(
      _PanelContainer2.default,
      { name: 'idPanel', collapsible: true },
      React.createElement(
        _Row2.default,
        null,
        React.createElement(
          'div',
          null,
          React.createElement(IDGeneratorInput, { name: 'objectNumber' }),
          React.createElement(TextInput, { name: 'numberOfObjects' }),
          React.createElement(
            CompoundInput,
            { name: 'otherNumberList' },
            React.createElement(
              CompoundInput,
              { name: 'otherNumber', tabular: true, repeating: true },
              React.createElement(TextInput, { name: 'numberValue' }),
              React.createElement(OptionControlledInput, { name: 'numberType', optionListName: 'numberTypes' })
            )
          ),
          React.createElement(
            CompoundInput,
            { name: 'responsibleDepartments' },
            React.createElement(OptionControlledInput, {
              name: 'responsibleDepartment',
              optionListName: 'departments',
              repeating: true
            })
          ),
          React.createElement(OptionControlledInput, { name: 'collection', optionListName: 'collections' }),
          React.createElement(OptionControlledInput, { name: 'recordStatus', optionListName: 'recordStatuses' })
        ),
        React.createElement(
          'div',
          null,
          React.createElement(
            CompoundInput,
            { name: 'briefDescriptions' },
            React.createElement(TextInput, { name: 'briefDescription', multiline: true, repeating: true })
          ),
          React.createElement(TextInput, { name: 'distinguishingFeatures', multiline: true }),
          React.createElement(
            CompoundInput,
            { name: 'comments' },
            React.createElement(TextInput, { name: 'comment', multiline: true, repeating: true })
          )
        )
      ),
      React.createElement(TextInput, { name: 'computedCurrentLocation' }),
      React.createElement(
        CompoundInput,
        { name: 'titleGroupList' },
        React.createElement(
          CompoundInput,
          { name: 'titleGroup', repeating: true },
          React.createElement(
            _PanelContainer2.default,
            null,
            React.createElement(
              _Row2.default,
              null,
              React.createElement(
                'div',
                null,
                React.createElement(TextInput, { name: 'title' }),
                React.createElement(VocabularyControlledInput, { name: 'titleLanguage', vocabularyName: 'languages' })
              ),
              React.createElement(
                'div',
                null,
                React.createElement(OptionControlledInput, { name: 'titleType', optionListName: 'titleTypes' }),
                React.createElement(
                  CompoundInput,
                  { name: 'titleTranslationSubGroupList' },
                  React.createElement(
                    CompoundInput,
                    { name: 'titleTranslationSubGroup', tabular: true, repeating: true },
                    React.createElement(TextInput, { name: 'titleTranslation' }),
                    React.createElement(VocabularyControlledInput, {
                      name: 'titleTranslationLanguage',
                      vocabularyName: 'languages'
                    })
                  )
                )
              )
            )
          )
        )
      ),
      React.createElement(
        CompoundInput,
        { name: 'objectNameList' },
        React.createElement(
          CompoundInput,
          { name: 'objectNameGroup', tabular: true, repeating: true },
          React.createElement(TextInput, { name: 'objectName' }),
          React.createElement(OptionControlledInput, { name: 'objectNameCurrency', optionListName: 'nameCurrencies' }),
          React.createElement(OptionControlledInput, { name: 'objectNameLevel', optionListName: 'nameLevels' }),
          React.createElement(OptionControlledInput, { name: 'objectNameSystem', optionListName: 'nameSystems' }),
          React.createElement(OptionControlledInput, { name: 'objectNameType', optionListName: 'nameTypes' }),
          React.createElement(VocabularyControlledInput, { name: 'objectNameLanguage', vocabularyName: 'languages' }),
          React.createElement(TextInput, { name: 'objectNameNote' })
        )
      )
    ),
    React.createElement(
      _PanelContainer2.default,
      { name: 'descPanel', collapsible: true },
      React.createElement(
        _Row2.default,
        null,
        React.createElement(
          'div',
          null,
          React.createElement(TextInput, { name: 'copyNumber' }),
          React.createElement(
            CompoundInput,
            { name: 'objectStatusList' },
            React.createElement(OptionControlledInput, {
              name: 'objectStatus',
              optionListName: 'objectStatuses',
              repeating: true
            })
          ),
          React.createElement(OptionControlledInput, { name: 'sex', optionListName: 'sexes' }),
          React.createElement(OptionControlledInput, { name: 'phase', optionListName: 'phases' }),
          React.createElement(
            CompoundInput,
            { name: 'forms' },
            React.createElement(OptionControlledInput, { name: 'form', optionListName: 'forms', repeating: true })
          )
        ),
        React.createElement(
          'div',
          null,
          React.createElement(TextInput, { name: 'editionNumber' }),
          React.createElement(
            CompoundInput,
            { tabular: true, msgkey: 'ageGroup' },
            React.createElement(TextInput, { name: 'age' }),
            React.createElement(VocabularyControlledInput, { name: 'ageQualifier', vocabularyName: 'agequalifier' }),
            React.createElement(OptionControlledInput, { name: 'ageUnit', optionListName: 'ageUnits' })
          ),
          React.createElement(
            CompoundInput,
            { name: 'styles' },
            React.createElement(TextInput, { name: 'style', repeating: true })
          ),
          React.createElement(
            CompoundInput,
            { name: 'colors' },
            React.createElement(TextInput, { name: 'color', repeating: true })
          )
        )
      ),
      React.createElement(
        CompoundInput,
        { name: 'materialGroupList' },
        React.createElement(
          CompoundInput,
          { name: 'materialGroup', tabular: true, repeating: true },
          React.createElement(TextInput, { name: 'material' }),
          React.createElement(TextInput, { name: 'materialComponent' }),
          React.createElement(TextInput, { name: 'materialComponentNote' }),
          React.createElement(TextInput, { name: 'materialName' }),
          React.createElement(TextInput, { name: 'materialSource' })
        )
      ),
      React.createElement(TextInput, { name: 'physicalDescription', multiline: true }),
      React.createElement(
        _Row2.default,
        null,
        React.createElement(
          'div',
          null,
          React.createElement(
            CompoundInput,
            { name: 'objectComponentGroupList' },
            React.createElement(
              CompoundInput,
              { name: 'objectComponentGroup', tabular: true, repeating: true },
              React.createElement(OptionControlledInput, {
                name: 'objectComponentName',
                optionListName: 'objectComponentNames'
              }),
              React.createElement(TextInput, { name: 'objectComponentInformation' })
            )
          )
        ),
        React.createElement(
          'div',
          null,
          React.createElement(
            CompoundInput,
            { name: 'technicalAttributeGroupList' },
            React.createElement(
              CompoundInput,
              { name: 'technicalAttributeGroup', tabular: true, repeating: true },
              React.createElement(OptionControlledInput, {
                name: 'technicalAttribute',
                optionListName: 'technicalAttributes'
              }),
              React.createElement(OptionControlledInput, {
                name: 'technicalAttributeMeasurement',
                optionListName: 'technicalAttributeMeasurements'
              }),
              React.createElement(OptionControlledInput, {
                name: 'technicalAttributeMeasurementUnit',
                optionListName: 'technicalAttributeMeasurementUnits'
              })
            )
          )
        )
      ),
      React.createElement(
        CompoundInput,
        { name: 'measuredPartGroupList' },
        React.createElement(
          CompoundInput,
          { name: 'measuredPartGroup', repeating: true },
          React.createElement(
            _PanelContainer2.default,
            null,
            React.createElement(
              _Row2.default,
              null,
              React.createElement(
                'div',
                null,
                React.createElement(OptionControlledInput, { name: 'measuredPart', optionListName: 'measuredParts' })
              ),
              React.createElement(
                'div',
                null,
                React.createElement(TextInput, { name: 'dimensionSummary' })
              )
            ),
            React.createElement(
              CompoundInput,
              { name: 'dimensionSubGroupList' },
              React.createElement(
                CompoundInput,
                { name: 'dimensionSubGroup', tabular: true, repeating: true },
                React.createElement(OptionControlledInput, { name: 'dimension', optionListName: 'dimensions' }),
                React.createElement(AuthorityControlledInput, {
                  name: 'measuredBy',
                  authority: 'person/person,person/person_shared,organization/organization,' + 'organization/organization_shared'
                }),
                React.createElement(OptionControlledInput, {
                  name: 'measurementMethod',
                  optionListName: 'measurementMethods'
                }),
                React.createElement(TextInput, { name: 'value' }),
                React.createElement(OptionControlledInput, { name: 'measurementUnit', optionListName: 'measurementUnits' }),
                React.createElement(TextInput, { name: 'valueQualifier' }),
                React.createElement(DateInput, { name: 'valueDate' })
              )
            )
          )
        )
      ),
      React.createElement(
        _PanelContainer2.default,
        { name: 'contentPanel', collapsible: true, collapsed: true },
        React.createElement(TextInput, { name: 'contentDescription', multiline: true }),
        React.createElement(
          _Row2.default,
          null,
          React.createElement(
            'div',
            null,
            React.createElement(
              CompoundInput,
              { name: 'contentLanguages' },
              React.createElement(VocabularyControlledInput, {
                name: 'contentLanguage',
                vocabularyName: 'languages',
                repeating: true
              })
            ),
            React.createElement(
              CompoundInput,
              { name: 'contentActivities' },
              React.createElement(TextInput, { name: 'contentActivity', repeating: true })
            ),
            React.createElement(
              CompoundInput,
              { name: 'contentConcepts' },
              React.createElement(AuthorityControlledInput, {
                name: 'contentConcept',
                authority: 'concept/concept,concept/material_ca,concept/material_ca_shared',
                repeating: true
              })
            ),
            React.createElement(StructuredDateInput, { name: 'contentDate' }),
            React.createElement(
              CompoundInput,
              { name: 'contentPositions' },
              React.createElement(OptionControlledInput, {
                name: 'contentPosition',
                optionListName: 'positions',
                repeating: true
              })
            ),
            React.createElement(
              CompoundInput,
              { name: 'contentObjectGroupList' },
              React.createElement(
                CompoundInput,
                { name: 'contentObjectGroup', tabular: true, repeating: true },
                React.createElement(TextInput, { name: 'contentObject' }),
                React.createElement(OptionControlledInput, {
                  name: 'contentObjectType',
                  optionListName: 'contentObjectTypes'
                })
              )
            )
          ),
          React.createElement(
            'div',
            null,
            React.createElement(
              CompoundInput,
              { name: 'contentPeoples' },
              React.createElement(TextInput, { name: 'contentPeople', repeating: true })
            ),
            React.createElement(
              CompoundInput,
              { name: 'contentPersons' },
              React.createElement(AuthorityControlledInput, {
                name: 'contentPerson',
                authority: 'person/person,person/person_shared,person/ulan_pa',
                repeating: true
              })
            ),
            React.createElement(
              CompoundInput,
              { name: 'contentPlaces' },
              React.createElement(TextInput, { name: 'contentPlace', repeating: true })
            ),
            React.createElement(
              CompoundInput,
              { name: 'contentScripts' },
              React.createElement(OptionControlledInput, { name: 'contentScript', optionListName: 'scripts', repeating: true })
            ),
            React.createElement(
              CompoundInput,
              { name: 'contentOrganizations' },
              React.createElement(AuthorityControlledInput, {
                name: 'contentOrganization',
                authority: 'organization/organization,organization/organization_shared,' + 'organization/ulan_oa',
                repeating: true
              })
            ),
            React.createElement(
              CompoundInput,
              { name: 'contentEventNameGroupList' },
              React.createElement(
                CompoundInput,
                { name: 'contentEventNameGroup', tabular: true, repeating: true },
                React.createElement(TextInput, { name: 'contentEventName' }),
                React.createElement(TextInput, { name: 'contentEventNameType' })
              )
            ),
            React.createElement(
              CompoundInput,
              { name: 'contentOtherGroupList' },
              React.createElement(
                CompoundInput,
                { name: 'contentOtherGroup', tabular: true, repeating: true },
                React.createElement(TextInput, { name: 'contentOther' }),
                React.createElement(TextInput, { name: 'contentOtherType' })
              )
            )
          )
        ),
        React.createElement(TextInput, { name: 'contentNote', multiline: true })
      ),
      React.createElement(
        _PanelContainer2.default,
        { name: 'textInscriptPanel', collapsible: true, collapsed: true },
        React.createElement(
          CompoundInput,
          { name: 'textualInscriptionGroupList' },
          React.createElement(
            CompoundInput,
            { name: 'textualInscriptionGroup', repeating: true },
            React.createElement(
              _PanelContainer2.default,
              null,
              React.createElement(TextInput, { name: 'inscriptionContent', multiline: true }),
              React.createElement(
                _Row2.default,
                null,
                React.createElement(
                  'div',
                  null,
                  React.createElement(AuthorityControlledInput, {
                    name: 'inscriptionContentInscriber',
                    authority: 'person/person,organization/organization,' + 'organization/organization_shared'
                  }),
                  React.createElement(VocabularyControlledInput, {
                    name: 'inscriptionContentLanguage',
                    vocabularyName: 'languages'
                  }),
                  React.createElement(StructuredDateInput, { name: 'inscriptionContentDateGroup' })
                ),
                React.createElement(
                  'div',
                  null,
                  React.createElement(OptionControlledInput, {
                    name: 'inscriptionContentPosition',
                    optionListName: 'positions'
                  }),
                  React.createElement(OptionControlledInput, {
                    name: 'inscriptionContentScript',
                    optionListName: 'scripts'
                  }),
                  React.createElement(OptionControlledInput, {
                    name: 'inscriptionContentType',
                    optionListName: 'inscriptionTypes'
                  }),
                  React.createElement(TextInput, { name: 'inscriptionContentMethod' })
                )
              ),
              React.createElement(TextInput, { name: 'inscriptionContentInterpretation', multiline: true }),
              React.createElement(TextInput, { name: 'inscriptionContentTranslation' }),
              React.createElement(TextInput, { name: 'inscriptionContentTransliteration' })
            )
          )
        )
      ),
      React.createElement(
        _PanelContainer2.default,
        { name: 'nonTextInscriptPanel', collapsible: true, collapsed: true },
        React.createElement(
          CompoundInput,
          { name: 'nonTextualInscriptionGroupList' },
          React.createElement(
            CompoundInput,
            { name: 'nonTextualInscriptionGroup', repeating: true },
            React.createElement(
              _PanelContainer2.default,
              null,
              React.createElement(TextInput, { name: 'inscriptionDescription', multiline: true }),
              React.createElement(
                _Row2.default,
                null,
                React.createElement(
                  'div',
                  null,
                  React.createElement(AuthorityControlledInput, {
                    name: 'inscriptionDescriptionInscriber',
                    authority: 'person/person,person/person_shared,organization/organization,' + 'organization/organization_shared'
                  }),
                  React.createElement(StructuredDateInput, { name: 'inscriptionDescriptionDateGroup' })
                ),
                React.createElement(
                  'div',
                  null,
                  React.createElement(OptionControlledInput, {
                    name: 'inscriptionDescriptionPosition',
                    optionListName: 'positions'
                  }),
                  React.createElement(OptionControlledInput, {
                    name: 'inscriptionDescriptionType',
                    optionListName: 'inscriptionTypes'
                  }),
                  React.createElement(TextInput, { name: 'inscriptionDescriptionMethod' })
                )
              ),
              React.createElement(TextInput, { name: 'inscriptionDescriptionInterpretation', multiline: true })
            )
          )
        )
      )
    ),
    React.createElement(
      _PanelContainer2.default,
      { name: 'prodPanel', collapsible: true, collapsed: true },
      React.createElement(
        _Row2.default,
        null,
        React.createElement(
          'div',
          null,
          React.createElement(
            CompoundInput,
            { name: 'objectProductionDateGroupList' },
            React.createElement(StructuredDateInput, { name: 'objectProductionDateGroup', repeating: true })
          ),
          React.createElement(
            CompoundInput,
            { name: 'techniqueGroupList' },
            React.createElement(
              CompoundInput,
              { name: 'techniqueGroup', tabular: true, repeating: true },
              React.createElement(TextInput, { name: 'technique' }),
              React.createElement(TextInput, { name: 'techniqueType' })
            )
          ),
          React.createElement(
            CompoundInput,
            { name: 'objectProductionPlaceGroupList' },
            React.createElement(
              CompoundInput,
              { name: 'objectProductionPlaceGroup', tabular: true, repeating: true },
              React.createElement(TextInput, { name: 'objectProductionPlace' }),
              React.createElement(TextInput, { name: 'objectProductionPlaceRole' })
            )
          ),
          React.createElement(
            CompoundInput,
            { name: 'objectProductionReasons' },
            React.createElement(TextInput, { name: 'objectProductionReason', multiline: true, repeating: true })
          )
        ),
        React.createElement(
          'div',
          null,
          React.createElement(
            CompoundInput,
            { name: 'objectProductionPeopleGroupList' },
            React.createElement(
              CompoundInput,
              { name: 'objectProductionPeopleGroup', tabular: true, repeating: true },
              React.createElement(TextInput, { name: 'objectProductionPeople' }),
              React.createElement(TextInput, { name: 'objectProductionPeopleRole' })
            )
          ),
          React.createElement(
            CompoundInput,
            { name: 'objectProductionPersonGroupList' },
            React.createElement(
              CompoundInput,
              { name: 'objectProductionPersonGroup', tabular: true, repeating: true },
              React.createElement(AuthorityControlledInput, {
                name: 'objectProductionPerson',
                authority: 'person/person,person/person_shared'
              }),
              React.createElement(TextInput, { name: 'objectProductionPersonRole' })
            )
          ),
          React.createElement(
            CompoundInput,
            { name: 'objectProductionOrganizationGroupList' },
            React.createElement(
              CompoundInput,
              { name: 'objectProductionOrganizationGroup', tabular: true, repeating: true },
              React.createElement(AuthorityControlledInput, {
                name: 'objectProductionOrganization',
                authority: 'organization/organization,organization/organization_shared'
              }),
              React.createElement(TextInput, { name: 'objectProductionOrganizationRole' })
            )
          ),
          React.createElement(TextInput, { name: 'objectProductionNote', multiline: true })
        )
      )
    ),
    React.createElement(
      _PanelContainer2.default,
      { name: 'histPanel', collapsible: true, collapsed: true },
      React.createElement(
        _PanelContainer2.default,
        { name: 'assocPanel', collapsible: true, collapsed: true },
        React.createElement(
          _Row2.default,
          null,
          React.createElement(
            'div',
            null,
            React.createElement(
              CompoundInput,
              { name: 'assocActivityGroupList' },
              React.createElement(
                CompoundInput,
                { name: 'assocActivityGroup', tabular: true, repeating: true },
                React.createElement(TextInput, { name: 'assocActivity' }),
                React.createElement(TextInput, { name: 'assocActivityType' }),
                React.createElement(TextInput, { name: 'assocActivityNote' })
              )
            ),
            React.createElement(
              CompoundInput,
              { name: 'assocObjectGroupList' },
              React.createElement(
                CompoundInput,
                { name: 'assocObjectGroup', tabular: true, repeating: true },
                React.createElement(TextInput, { name: 'assocObject' }),
                React.createElement(TextInput, { name: 'assocObjectType' }),
                React.createElement(TextInput, { name: 'assocObjectNote' })
              )
            ),
            React.createElement(
              CompoundInput,
              { name: 'assocConceptGroupList' },
              React.createElement(
                CompoundInput,
                { name: 'assocConceptGroup', tabular: true, repeating: true },
                React.createElement(AuthorityControlledInput, {
                  name: 'assocConcept',
                  authority: 'concept/concept'
                }),
                React.createElement(TextInput, { name: 'assocConceptType' }),
                React.createElement(TextInput, { name: 'assocConceptNote' })
              )
            ),
            React.createElement(
              CompoundInput,
              { name: 'assocCulturalContextGroupList' },
              React.createElement(
                CompoundInput,
                { name: 'assocCulturalContextGroup', tabular: true, repeating: true },
                React.createElement(TextInput, { name: 'assocCulturalContext' }),
                React.createElement(TextInput, { name: 'assocCulturalContextType' }),
                React.createElement(TextInput, { name: 'assocCulturalContextNote' })
              )
            ),
            React.createElement(
              CompoundInput,
              { name: 'assocOrganizationGroupList' },
              React.createElement(
                CompoundInput,
                { name: 'assocOrganizationGroup', tabular: true, repeating: true },
                React.createElement(AuthorityControlledInput, {
                  name: 'assocOrganization',
                  authority: 'organization/organization,organization/organization_shared'
                }),
                React.createElement(TextInput, { name: 'assocOrganizationType' }),
                React.createElement(TextInput, { name: 'assocOrganizationNote' })
              )
            ),
            React.createElement(
              CompoundInput,
              { name: 'assocPeopleGroupList' },
              React.createElement(
                CompoundInput,
                { name: 'assocPeopleGroup', tabular: true, repeating: true },
                React.createElement(TextInput, { name: 'assocPeople' }),
                React.createElement(TextInput, { name: 'assocPeopleType' }),
                React.createElement(TextInput, { name: 'assocPeopleNote' })
              )
            ),
            React.createElement(
              CompoundInput,
              { name: 'assocPersonGroupList' },
              React.createElement(
                CompoundInput,
                { name: 'assocPersonGroup', tabular: true, repeating: true },
                React.createElement(AuthorityControlledInput, {
                  name: 'assocPerson',
                  authority: 'person/person,person/person_shared'
                }),
                React.createElement(TextInput, { name: 'assocPersonType' }),
                React.createElement(TextInput, { name: 'assocPersonNote' })
              )
            ),
            React.createElement(
              CompoundInput,
              { name: 'assocPlaceGroupList' },
              React.createElement(
                CompoundInput,
                { name: 'assocPlaceGroup', tabular: true, repeating: true },
                React.createElement(TextInput, { name: 'assocPlace' }),
                React.createElement(TextInput, { name: 'assocPlaceType' }),
                React.createElement(TextInput, { name: 'assocPlaceNote' })
              )
            )
          ),
          React.createElement(
            'div',
            null,
            React.createElement(
              _PanelContainer2.default,
              null,
              React.createElement(
                CompoundInput,
                { tabular: true, msgkey: 'assocEventGroup' },
                React.createElement(TextInput, { name: 'assocEventName' }),
                React.createElement(TextInput, { name: 'assocEventNameType' })
              ),
              React.createElement(
                CompoundInput,
                { name: 'assocEventOrganizations' },
                React.createElement(AuthorityControlledInput, {
                  name: 'assocEventOrganization',
                  authority: 'organization/organization,organization/organization_shared',
                  repeating: true
                })
              ),
              React.createElement(
                CompoundInput,
                { name: 'assocEventPeoples' },
                React.createElement(TextInput, { name: 'assocEventPeople', repeating: true })
              ),
              React.createElement(
                CompoundInput,
                { name: 'assocEventPersons' },
                React.createElement(AuthorityControlledInput, {
                  name: 'assocEventPerson',
                  authority: 'person/person,person/person_shared',
                  repeating: true
                })
              ),
              React.createElement(
                CompoundInput,
                { name: 'assocEventPlaces' },
                React.createElement(TextInput, { name: 'assocEventPlace', repeating: true })
              ),
              React.createElement(TextInput, { name: 'assocEventNote' })
            ),
            React.createElement(
              CompoundInput,
              { name: 'assocDateGroupList' },
              React.createElement(
                CompoundInput,
                { name: 'assocDateGroup', tabular: true, repeating: true },
                React.createElement(StructuredDateInput, { name: 'assocStructuredDateGroup' }),
                React.createElement(TextInput, { name: 'assocDateType' }),
                React.createElement(TextInput, { name: 'assocDateNote' })
              )
            )
          )
        )
      ),
      React.createElement(TextInput, { name: 'objectHistoryNote', multiline: true }),
      React.createElement(
        CompoundInput,
        { name: 'usageGroupList' },
        React.createElement(
          CompoundInput,
          { name: 'usageGroup', tabular: true, repeating: true },
          React.createElement(TextInput, { name: 'usage' }),
          React.createElement(TextInput, { name: 'usageNote' })
        )
      ),
      React.createElement(
        _Row2.default,
        null,
        React.createElement(
          'div',
          null,
          React.createElement(
            CompoundInput,
            { name: 'owners' },
            React.createElement(AuthorityControlledInput, {
              name: 'owner',
              authority: 'person/person,person/person_shared,organization/organization,' + 'organization/organization_shared',
              repeating: true
            })
          ),
          React.createElement(
            CompoundInput,
            { name: 'ownershipDateGroupList' },
            React.createElement(StructuredDateInput, { name: 'ownershipDateGroup', repeating: true })
          )
        ),
        React.createElement(
          'div',
          null,
          React.createElement(
            _Row2.default,
            null,
            React.createElement(
              'div',
              null,
              React.createElement(OptionControlledInput, {
                name: 'ownershipAccess',
                optionListName: 'ownershipAccessLevels'
              })
            ),
            React.createElement(
              'div',
              null,
              React.createElement(OptionControlledInput, {
                name: 'ownershipCategory',
                optionListName: 'ownershipCategories'
              })
            )
          ),
          React.createElement(TextInput, { name: 'ownershipPlace' })
        )
      ),
      React.createElement(
        CompoundInput,
        { tabular: true, msgkey: 'ownershipExchangeGroup' },
        React.createElement(OptionControlledInput, {
          name: 'ownershipExchangeMethod',
          optionListName: 'ownershipExchangeMethods'
        }),
        React.createElement(TextInput, { name: 'ownershipExchangeNote' }),
        React.createElement(VocabularyControlledInput, {
          name: 'ownershipExchangePriceCurrency',
          vocabularyName: 'currency'
        }),
        React.createElement(TextInput, { name: 'ownershipExchangePriceValue' })
      )
    ),
    React.createElement(
      _PanelContainer2.default,
      { name: 'ownerPanel', collapsible: true, collapsed: true },
      React.createElement(TextInput, { name: 'ownersPersonalExperience', multiline: true }),
      React.createElement(TextInput, { name: 'ownersPersonalResponse', multiline: true }),
      React.createElement(
        CompoundInput,
        { name: 'ownersReferences' },
        React.createElement(TextInput, { name: 'ownersReference', repeating: true })
      ),
      React.createElement(TextInput, { name: 'ownersContributionNote', multiline: true })
    ),
    React.createElement(
      _PanelContainer2.default,
      { name: 'viewerPanel', collapsible: true, collapsed: true },
      React.createElement(TextInput, { name: 'viewersRole' }),
      React.createElement(TextInput, { name: 'viewersPersonalExperience', multiline: true }),
      React.createElement(TextInput, { name: 'viewersPersonalResponse', multiline: true }),
      React.createElement(
        CompoundInput,
        { name: 'viewersReferences' },
        React.createElement(TextInput, { name: 'viewersReference', repeating: true })
      ),
      React.createElement(TextInput, { name: 'viewersContributionNote', multiline: true })
    ),
    React.createElement(
      _PanelContainer2.default,
      { name: 'referencePanel', collapsible: true, collapsed: true },
      React.createElement(
        CompoundInput,
        { name: 'referenceGroupList' },
        React.createElement(
          CompoundInput,
          { name: 'referenceGroup', tabular: true, repeating: true },
          React.createElement(AuthorityControlledInput, {
            name: 'reference',
            authority: 'citation/citation,citation/citation_shared,citation/worldcat'
          }),
          React.createElement(TextInput, { name: 'referenceNote' })
        )
      )
    ),
    React.createElement(
      _PanelContainer2.default,
      { name: 'collectPanel', collapsible: true, collapsed: true },
      React.createElement(
        _Row2.default,
        null,
        React.createElement(
          'div',
          null,
          React.createElement(StructuredDateInput, { name: 'fieldCollectionDate' }),
          React.createElement(
            CompoundInput,
            { name: 'fieldCollectionMethods' },
            React.createElement(VocabularyControlledInput, {
              name: 'fieldCollectionMethod',
              vocabularyName: 'collectionmethod',
              repeating: true
            })
          ),
          React.createElement(TextInput, { name: 'fieldCollectionNote', multiline: true }),
          React.createElement(TextInput, { name: 'fieldCollectionNumber' })
        ),
        React.createElement(
          'div',
          null,
          React.createElement(AuthorityControlledInput, {
            name: 'fieldCollectionPlace',
            authority: 'place/place,place/place_shared,place/tgn_place'
          }),
          React.createElement(
            CompoundInput,
            { name: 'fieldCollectionSources' },
            React.createElement(AuthorityControlledInput, {
              name: 'fieldCollectionSource',
              authority: 'person/person,person/person_shared',
              repeating: true
            })
          ),
          React.createElement(
            CompoundInput,
            { name: 'fieldCollectors' },
            React.createElement(AuthorityControlledInput, {
              name: 'fieldCollector',
              authority: 'person/person,person/person_shared,organization/organization' + 'organization/organization_shared',
              repeating: true
            })
          ),
          React.createElement(
            CompoundInput,
            { name: 'fieldColEventNames' },
            React.createElement(TextInput, { name: 'fieldColEventName', repeating: true })
          )
        )
      )
    )
  );
};